@@ -53,22 +53,22 @@
 #define FIND_CACHE_SIZE   10
 
 /* Flags */
-#define H_LOOP          0x0001
-#define H_DAEMON        0x0002
-#define H_STREAM        0x0004
-#define H_NOISY         0x0008
-#define H_REPEATCOUNT   0x0010
-#define H_EMBED         0x0020
-#define H_NOEMBED       0x0040
-#define H_IGNORE_ERRORS 0x0080
-#define H_SWALLOW       0x0100
-#define H_MAXASPECT     0x0200
-#define H_FILL          0x0400
-#define H_NEEDS_XEMBED  0x0800
-#define H_CONTROLS      0x1000
-#define H_LINKS         0x2000
-#define H_FMATCH        0x4000
-#define H_AUTOSTART     0x8000
+#define H_LOOP          0x00001u
+#define H_DAEMON        0x00002u
+#define H_STREAM        0x00004u
+#define H_NOISY         0x00008u
+#define H_REPEATCOUNT   0x00010u
+#define H_EMBED         0x00020u
+#define H_NOEMBED       0x00040u
+#define H_IGNORE_ERRORS 0x00080u
+#define H_SWALLOW       0x00100u
+#define H_MAXASPECT     0x00200u
+#define H_FILL          0x00400u
+#define H_NEEDS_XEMBED  0x00800u
+#define H_CONTROLS      0x01000u
+#define H_LINKS         0x02000u
+#define H_FMATCH        0x04000u
+#define H_AUTOSTART     0x08000u
 
 /*****************************************************************************
  * Control use of semaphore in mozplugger-helper, define if one wants
@@ -80,19 +80,6 @@
 /*****************************************************************************
  * mozplugger-common.c functions
  *****************************************************************************/
-#ifdef DEBUG
-
-#define DEBUG_FILENAME "mozdebug"
-void close_debug(void);
-char * get_debug_path(void);
-
-#endif
-
-#ifdef __GNUC__
-void D(char *fmt, ...) __attribute__((format(printf,1,2)));
-#else
-void D(char *fmt, ...);
-#endif
 
 void my_kill(pid_t pid);
 
